bayespy.inference.vmp.nodes.gaussian_markov_chain.GaussianMarkovChainDistribution.random
========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. automethod:: GaussianMarkovChainDistribution.random